/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.cluster.api;

/**
 * Encapsulate a state of CMI server.
 * @author Loris Bouzonnet
 */
public class ServerState {

    /**
     * Server name.
     */
    private final String serverName;

    /**
     * True if the server is blacklisted.
     */
    private final boolean blacklisted;

    /**
     * Load factor.
     */
    private final int loadFactor;

    /**
     * Encapsulate a state of CMI server.
     * @param serverName server name
     * @param blacklisted true if the server is blacklisted
     * @param loadFactor load factor of the server
     */
    public ServerState(final String serverName, final boolean blacklisted, final int loadFactor) {
        this.serverName = serverName;
        this.blacklisted = blacklisted;
        this.loadFactor = loadFactor;
    }

    /**
     * @return server name
     */
    public String getServerName() {
        return serverName;
    }

    /**
     * @return load factor of the server
     */
    public int getLoadFactor() {
        return loadFactor;
    }

    /**
     * @return true if the server is blacklisted
     */
    public boolean isBlacklisted() {
        return blacklisted;
    }

}
